@@ -1,24 +1,20 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 #include <nan.h>
 #include "pi_est.h"  // NOLINT(build/include)
 #include "sync.h"  // NOLINT(build/include)
 
-using v8::Number;
-
 // Simple synchronous access to the `Estimate()` function
 NAN_METHOD(CalculateSync) {
-  NanScope();
-
   // expect a number as the first argument
-  int points = args[0]->Uint32Value();
+  int points = info[0]->Uint32Value();
   double est = Estimate(points);
 
-  NanReturnValue(NanNew<Number>(est));
+  info.GetReturnValue().Set(est);
 }
