@@ -1,9 +1,9 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 const test     = require('tap').test
@@ -13,19 +13,15 @@ const test     = require('tap').test
 
 test('bufferworkerpersistent', function (t) {
   var worker = bindings.a
-    , called = false
+    , called = 0
     , buf    = crypto.randomBytes(256)
     , bufHex = buf.toString('hex')
 
+  t.plan(7);
+
   t.type(worker, 'function')
 
-  setTimeout(function () {
-    t.ok(called, 'callback fired')
-    t.end()
-  }, 500)
-
   worker(200, buf, function (_buf) {
-    called = true
     t.ok(Buffer.isBuffer(_buf), 'is buffer arg')
     t.equal(_buf.toString('hex'), bufHex)
   })
