@@ -1,9 +1,9 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 const test     = require('tap').test
@@ -14,10 +14,9 @@ test('gc', function (t) {
   t.plan(3);
 
   t.type(bindings.hook, 'function');
+  t.type(bindings.check, 'function');
 
-  bindings.hook(function (from) {
-    t.ok(from == 'prologue' || from == 'epilogue');
-  });
-
+  bindings.hook();
   gc();
+  t.ok(bindings.check());
 });
