@@ -1,9 +1,9 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 const test     = require('tap').test
@@ -14,9 +14,9 @@ test('returnvalue', function (t) {
   t.plan(7);
   t.type(bindings.r, 'function');
   t.type(bindings.p, 'function');
-  t.type(bindings.s, 'function');
+  t.type(bindings.q, 'function');
   t.equal(bindings.r('a string value'), 'a string value');
   t.equal(bindings.r(), 'default');
   t.ok(bindings.p());
-  t.equal(bindings.s(), 'yes, it works');
+  t.ok(bindings.q());
 });
