@@ -1,9 +1,9 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2015 NAN contributors
+ * Copyright (c) 2016 NAN contributors
  *
- * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
 const test     = require('tap').test
@@ -12,22 +12,16 @@ const test     = require('tap').test
 
 
 test('FromV8String', function (t) {
-  t.plan(10);
+  t.plan(6);
 
-  var a = bindings.returnAsciiString;
-  var b = bindings.returnUtf8String;
-  var c = bindings.returnUcs2String;
-  var d = bindings.heapString;
+  var a = bindings.returnUtf8String;
+  var b = bindings.heapString;
 
   t.type(a, 'function');
   t.type(b, 'function');
-  t.type(c, 'function');
-  t.type(d, 'function');
 
-  t.equal(a('an ascii string'), 'an ascii string');
+  t.equal(a('an utf8 strïng'), 'an utf8 strïng');
   t.equal(b('an utf8 strïng'), 'an utf8 strïng');
-  t.equal(c('an ucs2 strïng'), 'an ucs2 strïng');
-  t.equal(d('an utf8 strïng'), 'an utf8 strïng');
 
   t.equal(bindings.encodeHex(), new Buffer('hello').toString('hex'));
   t.equal(bindings.encodeUCS2(), 'hello');
